@@ -171,6 +171,13 @@ cltq <- function(n = 20, p = 0.5, distn, params = list(), type = 7,
   if (distn == "chisq") {
     distn <- "chi-squared"
   }
+  # Check that revdbayes is installed, if it is needed
+  if (distn %in% c("gp", "gev")) {
+    if (!requireNamespace("revdbayes", quietly = TRUE)) {
+      stop("the revdbayes package is needed. Please install it.",
+           call. = FALSE)
+    }
+  }
   # Set the density, distribution, quantile and simulation functions.
   rfun <-
     switch(distn,
